## Typing stubs for pyinstaller

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`pyinstaller`](https://github.com/pyinstaller/pyinstaller) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `pyinstaller`. This version of
`types-pyinstaller` aims to provide accurate annotations for
`pyinstaller==6.14.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/pyinstaller`](https://github.com/python/typeshed/tree/main/stubs/pyinstaller)
directory.

This package was tested with
mypy 1.16.0,
pyright 1.1.400,
and pytype 2024.10.11.
It was generated from typeshed commit
[`0db0486fe6a0eb6b4ebf1256fe0afe0b95e2dc36`](https://github.com/python/typeshed/commit/0db0486fe6a0eb6b4ebf1256fe0afe0b95e2dc36).